<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Webブラウザなしでも大丈夫!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1はフリーソフトウェアですが、開発には貴重な時間が費やされています。</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="26"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>バグレポートやアイデアは%1までお願いします</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="33"/>
        <source>Icon designed by %1.</source>
        <translation>アイコンは%1さんのデザインです。</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>コンパクトモードは%1さんの貢献です。</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="35"/>
        <source>HTTP proxy support contributed by %1.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="38"/>
        <source>Translated by %1</source>
        <translation>翻訳は%1さん達の協力です</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="66"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;で配布されます</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="78"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>プログラムについて</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>%1について知りたいことがあったら、思いきって連絡をください</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="../src/downloaditem.cpp" line="295"/>
        <source>bytes</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="298"/>
        <source>KB</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="301"/>
        <source>MB</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="317"/>
        <source>bytes/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="320"/>
        <source>KB/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="323"/>
        <source>MB/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="329"/>
        <source>seconds</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="332"/>
        <source>minutes</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="335"/>
        <source>%4 %5 remaining</source>
        <translation/>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="53"/>
        <source>Continue</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="54"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="126"/>
        <source>%n Download(s)</source>
        <translation><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="../src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation/>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="../src/downloadview.cpp" line="18"/>
        <location filename="../src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation/>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Searching...</source>
        <translation>検索中...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>Show %1 More</source>
        <translation>さらに%1エントリ観る</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No videos</source>
        <translation>見つかりませんでした</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="50"/>
        <source>No more videos</source>
        <translation>見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="105"/>
        <source>&amp;Stop</source>
        <translation>ストップ(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="106"/>
        <source>Stop playback and go back to the search view</source>
        <translation>再生を停止させて、検索ビューに戻ります</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="112"/>
        <source>S&amp;kip</source>
        <translation>スキップ(&amp;k)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Skip to the next video</source>
        <translation>次の動画へ</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <location filename="../src/MainWindow.cpp" line="644"/>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="120"/>
        <location filename="../src/MainWindow.cpp" line="645"/>
        <source>Pause playback</source>
        <translation>再生を一時停止します</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <location filename="../src/MainWindow.cpp" line="728"/>
        <source>&amp;Full Screen</source>
        <translation>フルスクリーン(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="127"/>
        <source>Go full screen</source>
        <translation>フルスクリーン</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="136"/>
        <source>&amp;Compact mode</source>
        <translation>コンパクトモード(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>プレイリストとツールバーを隠す</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="145"/>
        <source>Open the &amp;YouTube page</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="146"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="152"/>
        <source>Copy the YouTube &amp;link</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="153"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="159"/>
        <source>Copy the video stream &amp;URL</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="160"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>&amp;Remove</source>
        <translation>削除(&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="167"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>プレイリストから選択した動画を削除</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="173"/>
        <source>Move &amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="174"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で上へ移動させます</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="180"/>
        <source>Move &amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で下へ移動させます</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="187"/>
        <source>&amp;Clear recent searches</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="192"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="199"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="200"/>
        <source>Bye</source>
        <translation>プログラムを終了</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="204"/>
        <source>&amp;Website</source>
        <translation>Webページへ(&amp;W)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="206"/>
        <source>%1 on the Web</source>
        <translation>%1のWebページを開きます</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="210"/>
        <source>Make a &amp;donation</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="211"/>
        <source>Please support the continued development of %1</source>
        <translation>%1の開発をサポートしてください！</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>プログラムについて(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="217"/>
        <source>Info about %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="225"/>
        <source>Search</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="244"/>
        <source>Mute volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="246"/>
        <source>Ctrl+M</source>
        <translation>Ctrl-M</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="277"/>
        <location filename="../src/MainWindow.cpp" line="959"/>
        <source>&amp;Downloads</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="278"/>
        <source>Show details about video downloads</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="286"/>
        <source>&amp;Download</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <source>Download the current video</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="328"/>
        <source>&amp;Application</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="336"/>
        <source>&amp;Playlist</source>
        <translation>プレイリスト(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>&amp;Video</source>
        <translation>動画(&amp;V)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="362"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="439"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="578"/>
        <location filename="../src/MainWindow.cpp" line="584"/>
        <source>Opening %1</source>
        <translation>%1を開いています</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="597"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="598"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="601"/>
        <source>Close and cancel download</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="602"/>
        <source>Wait for download to finish</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="635"/>
        <source>Fatal error: %1</source>
        <translation>致命的なエラー: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="637"/>
        <source>Error: %1</source>
        <translation>エラー: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="660"/>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="661"/>
        <source>Resume playback</source>
        <translation>再生再開します</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="751"/>
        <source>Exit &amp;Full Screen</source>
        <translation>フルスクリーンから戻る(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="834"/>
        <source>Remaining time: %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="892"/>
        <source>Volume at %1%</source>
        <translation>ボリューム%1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="898"/>
        <source>Volume is muted</source>
        <translation>音量OFFにしました</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="901"/>
        <source>Volume is unmuted</source>
        <translation>音量ONにしました</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="908"/>
        <source>Maximum video definition set to %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="944"/>
        <source>Your privacy is now safe</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="960"/>
        <source>Downloads complete</source>
        <translation/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="33"/>
        <source>Most relevant</source>
        <translation>関連度</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="40"/>
        <source>Most recent</source>
        <translation>新着</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="47"/>
        <source>Most viewed</source>
        <translation>閲覧回数</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="489"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="497"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="498"/>
        <source>The link will be valid only for a limited time.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="594"/>
        <source>This is just the demo version of %1.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="595"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="598"/>
        <source>Continue</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="599"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="625"/>
        <source>Downloading %1</source>
        <translation/>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="258"/>
        <source>Network error: %1</source>
        <translation>ネットワークエラー: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
        <source>%1 views</source>
        <translation>%1回 閲覧</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="74"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ようこそ&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;へ！</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="41"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="88"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="93"/>
        <source>a keyword</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="94"/>
        <source>a channel</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="99"/>
        <source>to start watching videos.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="124"/>
        <source>Watch</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="141"/>
        <source>Recent keywords</source>
        <translation>最近検索したキーワード</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="358"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>新しい%1があります。&lt;a href=&apos;%2&apos;&gt;バージョン%3へバージョンアップ&lt;/a&gt;しましょう</translation>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="35"/>
        <source>Make yourself comfortable</source>
        <translation>さあリラックスしましょう</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="186"/>
        <source>Cannot get video stream for %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/video.cpp" line="204"/>
        <source>Network error: %1 for %2</source>
        <translation>ネットワークエラー: %1 (%2へのアクセスにて)</translation>
    </message>
</context>
</TS>